@@ -41,12 +41,26 @@ use Weasel::FindExpanders qw/ register_find_expander /;
 Finds button tags or input tags of types submit, reset, button and image.
 
 Criteria:
- * 'id'
- * 'name'
- * 'text' -- button: matches content between open and close tag
-          -- input: matches 'value' attribute (shown on button),
+
+=over
+
+=item * 'id'
+
+=item * 'name'
+
+=item * 'text'
+
+=over
+
+=item * button: matches content between open and close tag
+
+=item * input: matches 'value' attribute (shown on button),
                     or image button's 'alt' attribute
 
+=back
+
+=back
+
 =cut
 
 sub button_expander {
@@ -81,9 +95,16 @@ sub button_expander {
 Finds input tags of type checkbox
 
 Criteria:
- * 'id'
- * 'name'
- * 'value'
+
+=over
+
+=item * 'id'
+
+=item * 'name'
+
+=item * 'value'
+
+=back
 
 =cut
 
@@ -117,8 +138,14 @@ sub contains_expander {
 Finds tags for which a label has been set (using the label tag)
 
 Criteria:
- * 'text': text of the label
- * 'tag': tags for which the label has been set
+
+=over
+
+=item * 'text': text of the label
+
+=item * 'tag': tags for which the label has been set
+
+=back
 
 =cut
 
@@ -130,12 +157,69 @@ sub labeled_expander {
     return ".//${tag}[\@id=//label[normalize-space(text())=normalize-space('$text')]/\@for]";
 }
 
+=item titled_expander
+
+Finds tags for which a title attribute has been set
+
+Criteria:
+
+=over
+
+=item * 'text': text of the title attribute
+
+=item * 'tag': tags for which the title has been set
+
+=back
+
+=cut
+
+sub titled_expander {
+    my %args = @_;
+
+    my $tag = $args{tag_name} // q{*};
+    my $text = $args{text};
+    return ".//${tag}[\@title=normalize-space('$text')";
+}
+
+=item field_expander
+
+Finds tags for which the id, name or title attribute has been set, or for which
+there's a label
+
+Criteria:
+
+=over
+
+=item * 'text': text of the attribute or label
+
+=item * 'tag': tags for which the attribute or has been set
+
+=back
+
+=cut
+
+sub field_expander {
+    my %args = @_;
+
+    my $tag = $args{tag_name} // q{*};
+    my $text = $args{text};
+    return join("\n|",
+                labeled_expander( %args ),
+                titled_expander( %args ),
+                ".//${tag}[\@id='$text' or \@name='$text']")
+}
+
 =item link_expander
 
 Finds A tags with an href attribute whose text or title matches 'text'
 
 Criteria:
- * 'text'
+
+=over
+
+=item * 'text'
+
+=back
 
 =cut
 
@@ -152,8 +236,14 @@ sub link_expander {
 Finds OPTION tags whose content matches 'text' or value matches 'value'
 
 Criteria:
- * 'text'
- * 'value'
+
+=over
+
+=item * 'text'
+
+=item * 'value'
+
+=back
 
 =cut
 
@@ -170,8 +260,14 @@ sub option_expander {
 Finds input tags of type password
 
 Criteria:
- * 'id'
- * 'name'
+
+=over
+
+=item * 'id'
+
+=item * 'name'
+
+=back
 
 =cut
 
@@ -193,8 +289,16 @@ sub password_expander {
 Finds input tags of type radio
 
 Criteria:
- * 'id'
- * 'name'
+
+=over
+
+=item * 'id'
+
+=item * 'name'
+
+=item * 'value'
+
+=back
 
 =cut
 
@@ -202,7 +306,7 @@ sub radio_expander {
     my %args = @_;
 
     my @clauses;
-    for my $clause (qw/ id name /) {
+    for my $clause (qw/ id name value /) {
         push @clauses, "\@$clause='$args{$clause}'"
             if defined $args{$clause};
     }
@@ -217,8 +321,14 @@ sub radio_expander {
 Finds select tags
 
 Criteria:
- * 'id'
- * 'name'
+
+=over
+
+=item * 'id'
+
+=item * 'name'
+
+=back
 
 =cut
 
@@ -239,8 +349,14 @@ sub select_expander {
 Finds input tags of type text or without type (which defaults to text)
 
 Criteria:
- * 'id'
- * 'name'
+
+=over
+
+=item * 'id'
+
+=item * 'name'
+
+=back
 
 =cut
 
@@ -261,13 +377,15 @@ register_find_expander($_->{name}, 'HTML', $_->{expander})
     for ({  name => 'button',   expander => \&button_expander   },
          {  name => 'checkbox', expander => \&checkbox_expander },
          {  name => 'contains', expander => \&contains_expander },
-         {  name => 'labeled',  expander => \&labeled_expander },
+         {  name => 'field',    expander => \&field_expander    },
+         {  name => 'labeled',  expander => \&labeled_expander  },
          {  name => 'link',     expander => \&link_expander     },
          {  name => 'option',   expander => \&option_expander   },
          {  name => 'password', expander => \&password_expander },
          {  name => 'radio',    expander => \&radio_expander    },
          {  name => 'select',   expander => \&select_expander   },
-         {  name => 'text',     expander => \&text_expander      },
+         {  name => 'text',     expander => \&text_expander     },
+         {  name => 'titled',   expander => \&titled_expander   },
     );
 
 =back
@@ -302,7 +420,7 @@ L<perl-weasel@googlegroups.com|mailto:perl-weasel@googlegroups.com>.
 
 =head1 LICENSE AND COPYRIGHT
 
- (C) 2016  Erik Huelsmann
+ (C) 2016-2023  Erik Huelsmann
 
 Licensed under the same terms as Perl.
 
